@@ -210,7 +210,8 @@ def getJournalDateForMedlineFile(elem,pmid):
 
 	if not pubYear is None:
 		pubYear = int(pubYear)
-		assert pubYear > 1700 and pubYear < 2100, 'Error extracting publication year for PMID=%s' % pmid
+		if not (pubYear > 1700 and pubYear < 2100):
+			pubYear = None
 
 	if not pubMonth is None:
 		if pubMonth in monthMapping:
@@ -278,17 +279,50 @@ def processMedlineFile(pubmedFile):
 				lastname = authorElem.find('./LastName')
 				collectivename = authorElem.find('./CollectiveName')
 
-				if not forename is None and not lastname is None:
+				name = None
+				if forename is not None and lastname is not None and forename.text is not None and lastname.text is not None:
 					name = "%s %s" % (forename.text, lastname.text)
-				if not lastname is None:
+				elif lastname is not None and lastname.text is not None:
 					name = lastname.text
-				elif not collectivename is None:
+				elif forename is not None and forename.text is not None:
+					name = forename.text
+				elif collectivename is not None and collectivename.text is not None:
 					name = collectivename.text
 				else:
 					raise RuntimeError("Unable to find authors in Pubmed citation (PMID=%s)" % pmid)
-
 				authors.append(name)
 
+			chemicals = []
+			chemicalElems = elem.findall('./MedlineCitation/ChemicalList/Chemical/NameOfSubstance')
+			for chemicalElem in chemicalElems:
+				chemID = chemicalElem.attrib['UI']
+				name = chemicalElem.text
+				#chemicals.append((chemID,name))
+				chemicals.append("%s|%s" % (chemID,name))
+			chemicalsTxt = "\t".join(chemicals)
+
+			meshHeadings = []
+			meshElems = elem.findall('./MedlineCitation/MeshHeadingList/MeshHeading')
+			for meshElem in meshElems:
+				descriptorElem = meshElem.find('./DescriptorName')
+				meshID = descriptorElem.attrib['UI']
+				majorTopicYN = descriptorElem.attrib['MajorTopicYN']
+				name = descriptorElem.text
+				#meshHeading = {'Descriptor':name,'MajorTopicYN':majorTopicYN,'ID':meshID,'Qualifiers':[]}
+				meshHeading = "Qualifier|%s|%s|%s" % (meshID,majorTopicYN,name)
+
+				qualifierElems = meshElem.findall('./QualifierName')
+				for qualifierElem in qualifierElems:
+					meshID = qualifierElem.attrib['UI']
+					majorTopicYN = qualifierElem.attrib['MajorTopicYN']
+					name = qualifierElem.text
+					qualifier = {'Descriptor':name,'MajorTopicYN':majorTopicYN,'ID':meshID}
+					#meshHeading['Qualifiers'].append(qualifier)
+					meshHeading += "%%Descriptor|%s|%s|%s" % (meshID,majorTopicYN,name)
+
+				meshHeadings.append(meshHeading)
+			meshHeadingsTxt = "\t".join(meshHeadings)
+					
 			# Extract the title of paper
 			title = elem.findall('./MedlineCitation/Article/ArticleTitle')
 			titleText = extractTextFromElemList(title)
@@ -319,6 +353,8 @@ def processMedlineFile(pubmedFile):
 			document["journal"] = journalTitle
 			document["journalISO"] = journalISOTitle
 			document["authors"] = authors
+			document["chemicals"] = chemicalsTxt
+			document["meshHeadings"] = meshHeadingsTxt
 
 			yield document
 		
@@ -378,7 +414,7 @@ def processPMCFile(pmcFile):
 					backText = extractTextFromElemList(articleElem.findall('./back'))
 					floatingText = extractTextFromElemList(articleElem.findall('./floats-group'))
 					
-					document = {'pmid':subPmidText, 'pmcid':subPmcidText, 'doi':subDoiText, 'pubYear':subPubYear, 'pubMonth':subPubMonth, 'pubDay':subPubDay, 'journal':journal, 'journalISO':journalISO}
+					document = {'pmid':subPmidText, 'pmcid':subPmcidText, 'doi':subDoiText, 'pubYear':subPubYear, 'pubMonth':subPubMonth, 'pubDay':subPubDay, 'journal':subJournal, 'journalISO':subJournalISO}
 
 					textSources = {}
 					textSources['title'] = titleText
@@ -435,7 +471,7 @@ def writeMarcXMLRecordToBiocFile(record,biocWriter):
 			offset += len(textSource)
 			biocDoc.add_passage(passage)
 
-	biocWriter.writedocument(biocDoc)
+	biocWriter.write_document(biocDoc)
 
 def uimaxmi2bioc(xmiFilename, biocFilename):
 	tree = etree.parse(xmiFilename)
@@ -447,7 +483,7 @@ def uimaxmi2bioc(xmiFilename, biocFilename):
 	contentNode = root.find('{http:///uima/cas.ecore}Sofa')
 	content = contentNode.attrib['sofaString']
 
-	with bioc.iterwrite(biocFilename) as writer:
+	with bioc.BioCXMLDocumentWriter(biocFilename) as writer:
 		biocDoc = bioc.BioCDocument()
 		biocDoc.id = None
 		biocDoc.infons['title'] = documentTitle
@@ -458,11 +494,11 @@ def uimaxmi2bioc(xmiFilename, biocFilename):
 		passage.offset = 0
 		biocDoc.add_passage(passage)
 
-		writer.writedocument(biocDoc)
+		writer.write_document(biocDoc)
 
 
 def pubmedxml2bioc(pubmedxmlFilename, biocFilename):
-	with bioc.iterwrite(biocFilename) as writer:
+	with bioc.BioCXMLDocumentWriter(biocFilename) as writer:
 		for pmDoc in processMedlineFile(pubmedxmlFilename):
 			biocDoc = bioc.BioCDocument()
 			biocDoc.id = pmDoc["pmid"]
@@ -474,6 +510,8 @@ def pubmedxml2bioc(pubmedxmlFilename, biocFilename):
 			biocDoc.infons['journal'] = pmDoc["journal"]
 			biocDoc.infons['journalISO'] = pmDoc["journalISO"]
 			biocDoc.infons['authors'] = ", ".join(pmDoc["authors"])
+			biocDoc.infons['chemicals'] = pmDoc['chemicals']
+			biocDoc.infons['meshHeadings'] = pmDoc['meshHeadings']
 	
 			offset = 0
 			for section in ["title","abstract"]:
@@ -486,13 +524,13 @@ def pubmedxml2bioc(pubmedxmlFilename, biocFilename):
 					offset += len(textSource)
 					biocDoc.add_passage(passage)
 
-			writer.writedocument(biocDoc)
+			writer.write_document(biocDoc)
 
 
 allowedSubsections = {"abbreviations","additional information","analysis","author contributions","authors' contributions","authors’ contributions","background","case report","competing interests","conclusion","conclusions","conflict of interest","conflicts of interest","consent","data analysis","data collection","discussion","ethics statement","funding","introduction","limitations","material and methods","materials","materials and methods","measures","method","methods","participants","patients and methods","pre-publication history","related literature","results","results and discussion","statistical analyses","statistical analysis","statistical methods","statistics","study design","summary","supplementary data","supplementary information","supplementary material","supporting information"}
 def pmcxml2bioc(pmcxmlFilename, biocFilename):
 	try:
-		with bioc.iterwrite(biocFilename) as writer:
+		with bioc.BioCXMLDocumentWriter(biocFilename) as writer:
 			for pmcDoc in processPMCFile(pmcxmlFilename):
 				biocDoc = bioc.BioCDocument()
 				biocDoc.id = pmcDoc["pmid"]
@@ -524,18 +562,20 @@ def pmcxml2bioc(pmcxmlFilename, biocFilename):
 						offset += len(textSource)
 						biocDoc.add_passage(passage)
 
-				writer.writedocument(biocDoc)
+				writer.write_document(biocDoc)
 	except etree.ParseError:
 		raise RuntimeError("Parsing error in PMC xml file: %s" % pmcxmlFilename)	
 
 def mergeBioc(biocFilename, outBiocWriter,idFilter):
-	with bioc.iterparse(biocFilename) as parser:
+	with open(biocFilename,'rb') as f:
+		parser = bioc.BioCXMLDocumentReader(f)
 		for biocDoc in parser:
 			if idFilter is None or biocDoc.id in idFilter:
-				outBiocWriter.writedocument(biocDoc)
+				outBiocWriter.write_document(biocDoc)
 
 def bioc2txt(biocFilename, txtHandle,idFilter):
-	with bioc.iterparse(biocFilename) as parser:
+	with open(biocFilename,'rb') as f:
+		parser = bioc.BioCXMLDocumentReader(f)
 		for biocDoc in parser:
 			if idFilter is None or biocDoc.id in idFilter:
 				for passage in biocDoc.passages:
@@ -543,7 +583,7 @@ def bioc2txt(biocFilename, txtHandle,idFilter):
 					txtHandle.write("\n\n")
 
 def marcxml2bioc(marcxmlFilename,biocFilename):
-	with open(marcxmlFilename,'rb') as inF, bioc.iterwrite(biocFilename) as writer:
+	with open(marcxmlFilename,'rb') as inF, bioc.BioCXMLDocumentWriter(biocFilename) as writer:
 		def marcxml2bioc_helper(record):
 			writeMarcXMLRecordToBiocFile(record,writer)
 
@@ -566,7 +606,7 @@ def convertFiles(inFiles,inFormat,outFile,outFormat,idFilterfiles=None):
 	outBiocHandle,outTxtHandle = None,None
 
 	if outFormat == 'bioc':
-		outBiocHandle = bioc.BioCEncoderIter(outFile)
+		outBiocHandle = bioc.BioCXMLDocumentWriter(outFile)
 	elif outFormat == 'txt':
 		outTxtHandle = codecs.open(outFile,'w','utf-8')
 
